@@ -6,11 +6,12 @@ package HTML::HTML5::DOM;
 
 	use 5.010;
 	use strict qw(vars subs);
+	use match::simple ();
 	use mro 'c3';
 
 	BEGIN {
 		$HTML::HTML5::DOM::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::VERSION   = '0.001';
+		$HTML::HTML5::DOM::VERSION   = '0.002';
 	};
 	
 	use constant XHTML_NS => 'http://www.w3.org/1999/xhtml';
@@ -22,7 +23,6 @@ package HTML::HTML5::DOM;
 	use IO::Detect qw//;
 	use Scalar::Util qw/blessed/;
 	use URI qw//;
-	use Web::Magic qw//;
 
 	sub getDOMImplementation
 	{
@@ -48,7 +48,7 @@ package HTML::HTML5::DOM;
 	{
 		my $self = shift;
 		my $test = blessed $_[0] ? $_[0] : HTML::HTML5::DOMutil::Feature->new(@_);
-		grep { $_ ~~ $test } @FEATURES;
+		grep match::simple::match($_, $test), @FEATURES;
 	}
 
 	sub registerFeature
@@ -125,7 +125,7 @@ package HTML::HTML5::DOM;
 	
 	BEGIN {
 		$HTML::HTML5::DOMutil::AutoDoc::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOMutil::AutoDoc::VERSION   = '0.001';
+		$HTML::HTML5::DOMutil::AutoDoc::VERSION   = '0.002';
 	};
 
 	use Capture::Attribute;
@@ -172,7 +172,7 @@ package HTML::HTML5::DOM;
 			q{=head1 AUTHOR},
 			q{Toby Inkster E<lt>tobyink@cpan.orgE<gt>.},
 			q{=head1 COPYRIGHT AND LICENCE},
-			q{This software is copyright (c) 2012 by Toby Inkster.},
+			q{This software is copyright (c) 2012, 2014 by Toby Inkster.},
 			q{This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.},
 			q{=head1 DISCLAIMER OF WARRANTIES},
 			q{THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.},
@@ -251,7 +251,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOMutil::Feature::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOMutil::Feature::VERSION   = '0.001';
+		$HTML::HTML5::DOMutil::Feature::VERSION   = '0.002';
 	};
 	
 	use strict qw(vars subs);
@@ -346,12 +346,15 @@ package HTML::HTML5::DOM;
 	use 5.010;
 	use strict qw(vars subs);
 	use mro 'c3';
-
+	
 	BEGIN {
 		$HTML::HTML5::DOMutil::FancyISA::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOMutil::FancyISA::VERSION   = '0.001';
+		$HTML::HTML5::DOMutil::FancyISA::VERSION   = '0.002';
 	};
 	
+	use Object::AUTHORITY ();
+	*AUTHORITY = \&Object::AUTHORITY::AUTHORITY;
+	
 	sub isa
 	{
 		my ($self, $isa) = @_;
@@ -375,7 +378,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLDocument::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLDocument::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLDocument::VERSION   = '0.002';
 	};
 
 	use base qw/HTML::HTML5::DOMutil::FancyISA/;
@@ -700,11 +703,10 @@ package HTML::HTML5::DOM;
 	use 5.010;
 	use strict;
 	use mro 'c3';
-	use Object::AUTHORITY;
-
+	
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLCollection::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLCollection::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLCollection::VERSION   = '0.002';
 	};
 	
 	use base qw/
@@ -721,7 +723,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLElement::VERSION   = '0.002';
 	};
 
 	our @ELEMENTS;
@@ -737,6 +739,7 @@ package HTML::HTML5::DOM;
 	use HTML::HTML5::Writer 0.104;
 	use List::Util 0 qw//;
 	use Scalar::Util 0 qw//;
+	use HTTP::Request 6.00 qw//;
 	use XML::LibXML 1.91 qw/:all/;
 	use XML::LibXML::Augment 0 -names => [@ELEMENTS];
 	use XML::LibXML::QuerySelector 0;
@@ -926,13 +929,13 @@ package HTML::HTML5::DOM;
 		*{"$class\::$subname"} = sub {
 			my $self = shift;
 			my $url  = $self->$via;
-			return Web::Magic->new(GET => "$url");
+			return HTTP::Request->new(GET => "$url");
 		};
 
 		HTML::HTML5::DOMutil::AutoDoc->add(
 			$class,
 			$subname,
-			sprintf('Shortcut for C<< Web::Magic->new(GET => $elem->%s) >>', $via),
+			sprintf('Shortcut for C<< HTTP::Request->new(GET => $elem->%s) >>', $via),
 			);
 	}
 
@@ -941,7 +944,7 @@ package HTML::HTML5::DOM;
 		my ($class, $todo) = @_;
 		$todo ||= sub { 1 };
 		
-		if ('form' ~~ $todo)
+		if (match::simple::match('form', $todo))
 		{
 			*{"$class\::form"} = sub
 			{
@@ -965,7 +968,7 @@ package HTML::HTML5::DOM;
 		
 		foreach my $x (qw/Action Enctype Method NoValidate Target/)
 		{
-			next unless lc("form$x") ~~ $todo;
+			next unless match::simple::match(lc("form$x"), $todo);
 			
 			*{"$class\::form$x"} = sub
 			{
@@ -1246,7 +1249,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLUnknownElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLUnknownElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLUnknownElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1268,7 +1271,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLAnchorElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLAnchorElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLAnchorElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1297,7 +1300,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLAreaElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLAreaElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLAreaElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1326,7 +1329,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLAudioElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLAudioElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLAudioElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1348,7 +1351,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLMediaElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLMediaElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLMediaElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1375,7 +1378,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLBaseElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLBaseElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLBaseElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1400,7 +1403,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLQuoteElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLQuoteElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLQuoteElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1424,7 +1427,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLBodyElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLBodyElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLBodyElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1446,7 +1449,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLBRElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLBRElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLBRElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1468,7 +1471,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLButtonElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLButtonElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLButtonElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1494,7 +1497,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLCanvasElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLCanvasElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLCanvasElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -1518,7 +1521,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTableCaptionElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTableCaptionElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTableCaptionElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1540,7 +1543,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTableColElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTableColElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTableColElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1583,7 +1586,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLCommandElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLCommandElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLCommandElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1609,7 +1612,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLDataListElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLDataListElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLDataListElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1637,7 +1640,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLModElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLModElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLModElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1661,7 +1664,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLDetailsElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLDetailsElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLDetailsElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -1685,7 +1688,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLDivElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLDivElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLDivElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1707,7 +1710,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLDListElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLDListElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLDListElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1729,7 +1732,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLEmbedElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLEmbedElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLEmbedElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -1753,7 +1756,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLFieldSetElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLFieldSetElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLFieldSetElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1800,7 +1803,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLFormElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLFormElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLFormElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -1825,7 +1828,7 @@ package HTML::HTML5::DOM;
 			-> ownerDocument
 			-> getElementsByTagName('*')
 			-> grep(sub {
-					($_->nodeName ~~ $allowed)
+					match::simple::match($_->nodeName, $allowed)
 					&& ($_->form == $self)
 				})
 			-> map(sub { XML::LibXML::Augment->rebless($_) });
@@ -1881,14 +1884,15 @@ package HTML::HTML5::DOM;
 
 		if ($method eq 'GET')
 		{
-			return Web::Magic->new($self->action.'?'.$fields)
+			return HTTP::Request->new(GET => $self->action.'?'.$fields)
 		}
 
-		return Web::Magic
-			-> new($self->action)
-			-> set_request_method($method)
-			-> Content_Type($self->enctype || 'application/x-www-form-urlencoded')
-			-> set_request_body($fields);
+		HTTP::Request->new(
+			$method,
+			$self->action,
+			[ 'Content-Type' => $self->enctype || 'application/x-www-form-urlencoded' ],
+			$fields,
+		);
 	}
 
 	HTML::HTML5::DOMutil::AutoDoc->add(
@@ -1902,7 +1906,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLFormControlsCollection::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLFormControlsCollection::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLFormControlsCollection::VERSION   = '0.002';
 	};
 	
 	use base qw/HTML::HTML5::DOM::HTMLCollection/;
@@ -1983,7 +1987,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::RadioNodeList::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::RadioNodeList::VERSION   = '0.001';
+		$HTML::HTML5::DOM::RadioNodeList::VERSION   = '0.002';
 	};
 		
 	use base qw/XML::LibXML::NodeList/;
@@ -2012,7 +2016,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLHeadElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLHeadElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLHeadElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2050,7 +2054,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLHeadingElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLHeadingElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLHeadingElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2072,7 +2076,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLHRElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLHRElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLHRElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2094,7 +2098,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLHtmlElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLHtmlElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLHtmlElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -2118,7 +2122,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLIFrameElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLIFrameElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLIFrameElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2144,7 +2148,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLImageElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLImageElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLImageElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2171,7 +2175,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLInputElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLInputElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLInputElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -2231,7 +2235,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLKeygenElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLKeygenElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLKeygenElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2256,7 +2260,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLLabelElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLLabelElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLLabelElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2305,7 +2309,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLLegendElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLLegendElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLLegendElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2329,7 +2333,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLLIElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLLIElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLLIElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -2356,7 +2360,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLLinkElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLLinkElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLLinkElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2385,7 +2389,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLMapElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLMapElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLMapElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2407,7 +2411,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLMenuElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLMenuElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLMenuElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2431,7 +2435,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLMetaElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLMetaElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLMetaElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2455,7 +2459,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLMeterElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLMeterElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLMeterElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2481,7 +2485,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLObjectElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLObjectElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLObjectElement::VERSION   = '0.002';
 	};
 
 	our @ELEMENTS;
@@ -2509,7 +2513,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLOListElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLOListElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLOListElement::VERSION   = '0.002';
 	};
 
 	our @ELEMENTS;
@@ -2533,7 +2537,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLOptGroupElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLOptGroupElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLOptGroupElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2557,7 +2561,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLOptionElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLOptionElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLOptionElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -2579,7 +2583,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLOutputElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLOutputElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLOutputElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2604,7 +2608,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLParagraphElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLParagraphElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLParagraphElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -2626,7 +2630,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLParamElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLParamElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLParamElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2650,7 +2654,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLPreElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLPreElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLPreElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2672,7 +2676,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLProgressElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLProgressElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLProgressElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2697,7 +2701,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLScriptElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLScriptElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLScriptElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2723,7 +2727,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLSelectElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLSelectElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLSelectElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2748,7 +2752,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLSourceElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLSourceElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLSourceElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2775,7 +2779,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLSpanElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLSpanElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLSpanElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -2797,7 +2801,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLStyleElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLStyleElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLStyleElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -2823,7 +2827,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTableElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTableElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTableElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2895,7 +2899,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTableSectionElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTableSectionElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTableSectionElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2933,7 +2937,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTableCellElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTableCellElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTableCellElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -2981,7 +2985,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTableDataCellElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTableDataCellElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTableDataCellElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -3003,7 +3007,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTableHeaderCellElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTableHeaderCellElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTableHeaderCellElement::VERSION   = '0.002';
 	};
 		
 	our @ELEMENTS;
@@ -3027,7 +3031,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTableRowElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTableRowElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTableRowElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -3067,7 +3071,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTextAreaElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTextAreaElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTextAreaElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -3092,7 +3096,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTimeElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTimeElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTimeElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -3119,7 +3123,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTitleElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTitleElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTitleElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -3143,7 +3147,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLTrackElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLTrackElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLTrackElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -3165,7 +3169,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLUListElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLUListElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLUListElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -3187,7 +3191,7 @@ package HTML::HTML5::DOM;
 
 	BEGIN {
 		$HTML::HTML5::DOM::HTMLVideoElement::AUTHORITY = 'cpan:TOBYINK';
-		$HTML::HTML5::DOM::HTMLVideoElement::VERSION   = '0.001';
+		$HTML::HTML5::DOM::HTMLVideoElement::VERSION   = '0.002';
 	};
 	
 	our @ELEMENTS;
@@ -3269,8 +3273,8 @@ Methods that return a datetime, generally return one blessed into the
 L<DateTime> class.
 
 Methods that result in hypertext navigation (e.g. clicking a link or
-submitting a form) generally return a L<Web::Magic> object (which is
-basically an HTTP request waiting to happen).
+submitting a form) generally return an L<HTTP::Request> object (which
+you can pass to an L<LWP::UserAgent> or L<WWW::Mechanize> instance).
 
 The standard Perl C<isa> method is overridden to support two additional
 calling styles:
@@ -3528,7 +3532,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 by Toby Inkster.
+This software is copyright (c) 2012, 2014 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under the
 same terms as the Perl 5 programming language system itself.
